@@ -63,7 +63,6 @@ def which(program):
             exe_file = os.path.join(path, program)
             if is_exe(exe_file):
                 return exe_file
-
     return None
 
 
@@ -239,22 +238,6 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
     common.create_symlink(catkin_toplevel, os.path.join(build_source_dir, "CMakeLists.txt"))
     underlays = ';'.join(underlays_list)
 
-    ##########################
-    # Toolchain
-    ##########################
-    if not toolchain_ == "":
-        toolchains_dir = os.path.join(os.path.dirname(__file__), 'toolchains')
-        if os.path.isfile(os.path.join(toolchains_dir, toolchain_ + ".cmake")):
-            shutil.copy(os.path.join(toolchains_dir, toolchain_ + ".cmake"), os.path.join(build_dir, "toolchain.cmake"))
-
-    ##########################
-    # Platform
-    ##########################
-    if not platform_ == "":
-        platforms_dir = os.path.join(os.path.dirname(__file__), 'platforms')
-        if os.path.isfile(os.path.join(platforms_dir, platform_ + ".cmake")):
-            shutil.copy(os.path.join(platforms_dir, platform_ + ".cmake"), os.path.join(build_dir, "platform.cmake"))
-
     ##########################
     # Other Args
     ##########################
@@ -271,10 +254,27 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
     print_build_details(build_dir, source_dir, install_prefix, build_type, underlays, name, toolchain_, platform_)
     os.chdir(build_dir)
 
+    ##########################
+    # Toolchain
+    ##########################
+    if not toolchain_ == "":
+        toolchains_dir = os.path.join(os.path.dirname(__file__), 'toolchains')
+        if os.path.isfile(os.path.join(toolchains_dir, toolchain_ + ".cmake")):
+            shutil.copy(os.path.join(toolchains_dir, toolchain_ + ".cmake"), os.path.join(build_dir, "toolchain.cmake"))
+
+    ##########################
+    # Platform
+    ##########################
+    platform_content = ""
+    if not platform_ == "":
+        platforms_dir = os.path.join(os.path.dirname(__file__), 'platforms')
+        if os.path.isfile(os.path.join(platforms_dir, platform_ + ".cmake")):
+            shutil.copy(os.path.join(platforms_dir, platform_ + ".cmake"), os.path.join(build_dir, "platform.cmake"))
+
     ##########################
     # Cache
     ##########################
-    instantiate_config_cmake(build_dir, build_type, install_prefix, underlays)
+    instantiate_config_cmake(platform_content, build_dir, build_type, install_prefix, underlays)
 
     ##########################
     # Templates
